
/* Generated data (by glib-mkenums) */


#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif /* HAVE_CONFIG_H */
#include <numcosmo/numcosmo.h>

/* enumerations from "nc_hicosmo.h" */
GType
nc_hi_cosmo_impl_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { NC_HICOSMO_IMPL_H0, "NC_HICOSMO_IMPL_H0", "h0" },
        { NC_HICOSMO_IMPL_Omega_b, "NC_HICOSMO_IMPL_Omega_b", "omega-b" },
        { NC_HICOSMO_IMPL_Omega_r, "NC_HICOSMO_IMPL_Omega_r", "omega-r" },
        { NC_HICOSMO_IMPL_Omega_c, "NC_HICOSMO_IMPL_Omega_c", "omega-c" },
        { NC_HICOSMO_IMPL_Omega_t, "NC_HICOSMO_IMPL_Omega_t", "omega-t" },
        { NC_HICOSMO_IMPL_sigma_8, "NC_HICOSMO_IMPL_sigma_8", "sigma-8" },
        { NC_HICOSMO_IMPL_T_gamma0, "NC_HICOSMO_IMPL_T_gamma0", "t-gamma0" },
        { NC_HICOSMO_IMPL_z_lss, "NC_HICOSMO_IMPL_z_lss", "z-lss" },
        { NC_HICOSMO_IMPL_E2, "NC_HICOSMO_IMPL_E2", "e2" },
        { NC_HICOSMO_IMPL_dE2_dz, "NC_HICOSMO_IMPL_dE2_dz", "de2-dz" },
        { NC_HICOSMO_IMPL_d2E2_dz2, "NC_HICOSMO_IMPL_d2E2_dz2", "d2e2-dz2" },
        { NC_HICOSMO_IMPL_cd, "NC_HICOSMO_IMPL_cd", "cd" },
        { NC_HICOSMO_IMPL_powspec, "NC_HICOSMO_IMPL_powspec", "powspec" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("NcHICosmoImpl"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "model/nc_hicosmo_de.h" */
GType
nc_hi_cosmo_de_impl_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { NC_HICOSMO_DE_IMPL_weff, "NC_HICOSMO_DE_IMPL_weff", "weff" },
        { NC_HICOSMO_DE_IMPL_dweff_dz, "NC_HICOSMO_DE_IMPL_dweff_dz", "dweff-dz" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("NcHICosmoDEImpl"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
GType
nc_hi_cosmo_de_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_DE_H0, "NC_HICOSMO_DE_H0", "h0" },
        { NC_HICOSMO_DE_OMEGA_C, "NC_HICOSMO_DE_OMEGA_C", "omega-c" },
        { NC_HICOSMO_DE_OMEGA_X, "NC_HICOSMO_DE_OMEGA_X", "omega-x" },
        { NC_HICOSMO_DE_T_GAMMA0, "NC_HICOSMO_DE_T_GAMMA0", "t-gamma0" },
        { NC_HICOSMO_DE_OMEGA_B, "NC_HICOSMO_DE_OMEGA_B", "omega-b" },
        { NC_HICOSMO_DE_SPECINDEX, "NC_HICOSMO_DE_SPECINDEX", "specindex" },
        { NC_HICOSMO_DE_SIGMA8, "NC_HICOSMO_DE_SIGMA8", "sigma8" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoDEParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "model/nc_hicosmo_de_linder.h" */
GType
nc_hi_cosmo_de_linder_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_DE_LINDER_W0, "NC_HICOSMO_DE_LINDER_W0", "w0" },
        { NC_HICOSMO_DE_LINDER_W1, "NC_HICOSMO_DE_LINDER_W1", "w1" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoDELinderParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "model/nc_hicosmo_de_pad.h" */
GType
nc_hi_cosmo_de_pad_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_DE_PAD_W0, "NC_HICOSMO_DE_PAD_W0", "w0" },
        { NC_HICOSMO_DE_PAD_W1, "NC_HICOSMO_DE_PAD_W1", "w1" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoDEPadParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "model/nc_hicosmo_de_qe.h" */
GType
nc_hi_cosmo_deqe_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_DE_QE_W0, "NC_HICOSMO_DE_QE_W0", "w0" },
        { NC_HICOSMO_DE_QE_W1, "NC_HICOSMO_DE_QE_W1", "w1" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoDEQEParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "model/nc_hicosmo_de_xcdm.h" */
GType
nc_hi_cosmo_dexcdm_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_DE_XCDM_W, "NC_HICOSMO_DE_XCDM_W", "w" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoDEXCDMParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "model/nc_hicosmo_qconst.h" */
GType
nc_hi_cosmo_qconst_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_QCONST_H0, "NC_HICOSMO_QCONST_H0", "h0" },
        { NC_HICOSMO_QCONST_OMEGA_T, "NC_HICOSMO_QCONST_OMEGA_T", "omega-t" },
        { NC_HICOSMO_QCONST_CD, "NC_HICOSMO_QCONST_CD", "cd" },
        { NC_HICOSMO_QCONST_E, "NC_HICOSMO_QCONST_E", "e" },
        { NC_HICOSMO_QCONST_Q, "NC_HICOSMO_QCONST_Q", "q" },
        { NC_HICOSMO_QCONST_Z1, "NC_HICOSMO_QCONST_Z1", "z1" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoQConstParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "model/nc_hicosmo_qlinear.h" */
GType
nc_hi_cosmo_qlinear_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_QLINEAR_H0, "NC_HICOSMO_QLINEAR_H0", "h0" },
        { NC_HICOSMO_QLINEAR_OMEGA_T, "NC_HICOSMO_QLINEAR_OMEGA_T", "omega-t" },
        { NC_HICOSMO_QLINEAR_CD, "NC_HICOSMO_QLINEAR_CD", "cd" },
        { NC_HICOSMO_QLINEAR_E, "NC_HICOSMO_QLINEAR_E", "e" },
        { NC_HICOSMO_QLINEAR_Q, "NC_HICOSMO_QLINEAR_Q", "q" },
        { NC_HICOSMO_QLINEAR_QP, "NC_HICOSMO_QLINEAR_QP", "qp" },
        { NC_HICOSMO_QLINEAR_Z1, "NC_HICOSMO_QLINEAR_Z1", "z1" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoQLinearParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "model/nc_hicosmo_qpw.h" */
GType
nc_hi_cosmo_qpws_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_QPW_H0, "NC_HICOSMO_QPW_H0", "h0" },
        { NC_HICOSMO_QPW_OMEGA_T, "NC_HICOSMO_QPW_OMEGA_T", "omega-t" },
        { NC_HICOSMO_QPW_Q0, "NC_HICOSMO_QPW_Q0", "q0" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoQPWSParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
GType
nc_hi_cosmo_qpwv_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_QPW_QP, "NC_HICOSMO_QPW_QP", "qp" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoQPWVParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "model/nc_hicosmo_qspline.h" */
GType
nc_hi_cosmo_qspline_sparams_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_QSPLINE_H0, "NC_HICOSMO_QSPLINE_H0", "h0" },
        { NC_HICOSMO_QSPLINE_OMEGA_T, "NC_HICOSMO_QSPLINE_OMEGA_T", "omega-t" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoQSplineSParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
GType
nc_hi_cosmo_qspline_vparams_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_HICOSMO_QSPLINE_Q, "NC_HICOSMO_QSPLINE_Q", "q" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcHICosmoQSplineVParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "lss/nc_matter_var.h" */
GType
nc_matter_var_strategy_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_MATTER_VAR_NUMINT, "NC_MATTER_VAR_NUMINT", "numint" },
        { NC_MATTER_VAR_SPLINEINT, "NC_MATTER_VAR_SPLINEINT", "splineint" },
        { NC_MATTER_VAR_FFT, "NC_MATTER_VAR_FFT", "fft" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcMatterVarStrategy"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "lss/nc_mass_function.h" */
GType
nc_mass_function_spline_optimize_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_MASS_FUNCTION_SPLINE_NONE, "NC_MASS_FUNCTION_SPLINE_NONE", "none" },
        { NC_MASS_FUNCTION_SPLINE_LNM, "NC_MASS_FUNCTION_SPLINE_LNM", "lnm" },
        { NC_MASS_FUNCTION_SPLINE_Z, "NC_MASS_FUNCTION_SPLINE_Z", "z" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcMassFunctionSplineOptimize"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "lss/nc_cluster_redshift.h" */
GType
nc_cluster_redshift_impl_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { NC_CLUSTER_REDSHIFT_P, "NC_CLUSTER_REDSHIFT_P", "p" },
        { NC_CLUSTER_REDSHIFT_INTP, "NC_CLUSTER_REDSHIFT_INTP", "intp" },
        { NC_CLUSTER_REDSHIFT_RESAMPLE, "NC_CLUSTER_REDSHIFT_RESAMPLE", "resample" },
        { NC_CLUSTER_REDSHIFT_P_LIMITS, "NC_CLUSTER_REDSHIFT_P_LIMITS", "p-limits" },
        { NC_CLUSTER_REDSHIFT_N_LIMTS, "NC_CLUSTER_REDSHIFT_N_LIMTS", "n-limts" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("NcClusterRedshiftImpl"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "lss/nc_cluster_mass.h" */
GType
nc_cluster_mass_impl_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { NC_CLUSTER_MASS_P, "NC_CLUSTER_MASS_P", "p" },
        { NC_CLUSTER_MASS_INTP, "NC_CLUSTER_MASS_INTP", "intp" },
        { NC_CLUSTER_MASS_RESAMPLE, "NC_CLUSTER_MASS_RESAMPLE", "resample" },
        { NC_CLUSTER_MASS_P_LIMITS, "NC_CLUSTER_MASS_P_LIMITS", "p-limits" },
        { NC_CLUSTER_MASS_N_LIMITS, "NC_CLUSTER_MASS_N_LIMITS", "n-limits" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_flags_register_static (g_intern_static_string ("NcClusterMassImpl"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "lss/nc_cluster_mass_vanderlinde.h" */
GType
nc_cluster_mass_vanderlinde_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_CLUSTER_MASS_VANDERLINDE_A_SZ, "NC_CLUSTER_MASS_VANDERLINDE_A_SZ", "a-sz" },
        { NC_CLUSTER_MASS_VANDERLINDE_B_SZ, "NC_CLUSTER_MASS_VANDERLINDE_B_SZ", "b-sz" },
        { NC_CLUSTER_MASS_VANDERLINDE_C_SZ, "NC_CLUSTER_MASS_VANDERLINDE_C_SZ", "c-sz" },
        { NC_CLUSTER_MASS_VANDERLINDE_D_SZ, "NC_CLUSTER_MASS_VANDERLINDE_D_SZ", "d-sz" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcClusterMassVanderlindeParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "lss/nc_cluster_mass_benson.h" */
GType
nc_cluster_mass_benson_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_CLUSTER_MASS_BENSON_A_SZ, "NC_CLUSTER_MASS_BENSON_A_SZ", "a-sz" },
        { NC_CLUSTER_MASS_BENSON_B_SZ, "NC_CLUSTER_MASS_BENSON_B_SZ", "b-sz" },
        { NC_CLUSTER_MASS_BENSON_C_SZ, "NC_CLUSTER_MASS_BENSON_C_SZ", "c-sz" },
        { NC_CLUSTER_MASS_BENSON_D_SZ, "NC_CLUSTER_MASS_BENSON_D_SZ", "d-sz" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcClusterMassBensonParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "lss/nc_cluster_mass_benson_xray.h" */
GType
nc_cluster_mass_benson_xray_params_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_CLUSTER_MASS_BENSON_XRAY_A_SZ, "NC_CLUSTER_MASS_BENSON_XRAY_A_SZ", "a-sz" },
        { NC_CLUSTER_MASS_BENSON_XRAY_B_SZ, "NC_CLUSTER_MASS_BENSON_XRAY_B_SZ", "b-sz" },
        { NC_CLUSTER_MASS_BENSON_XRAY_C_SZ, "NC_CLUSTER_MASS_BENSON_XRAY_C_SZ", "c-sz" },
        { NC_CLUSTER_MASS_BENSON_XRAY_D_SZ, "NC_CLUSTER_MASS_BENSON_XRAY_D_SZ", "d-sz" },
        { NC_CLUSTER_MASS_BENSON_XRAY_A_X, "NC_CLUSTER_MASS_BENSON_XRAY_A_X", "a-x" },
        { NC_CLUSTER_MASS_BENSON_XRAY_B_X, "NC_CLUSTER_MASS_BENSON_XRAY_B_X", "b-x" },
        { NC_CLUSTER_MASS_BENSON_XRAY_C_X, "NC_CLUSTER_MASS_BENSON_XRAY_C_X", "c-x" },
        { NC_CLUSTER_MASS_BENSON_XRAY_D_X, "NC_CLUSTER_MASS_BENSON_XRAY_D_X", "d-x" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcClusterMassBensonXRayParams"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "lss/nc_data_cluster_abundance.h" */
GType
nc_data_cluster_abundance_id_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_DATA_CLUSTER_ABUNDANCE_FIT, "NC_DATA_CLUSTER_ABUNDANCE_FIT", "fit" },
        { NC_DATA_CLUSTER_ABUNDANCE_TXT, "NC_DATA_CLUSTER_ABUNDANCE_TXT", "txt" },
        { NC_DATA_CLUSTER_ABUNDANCE_SAMPLING, "NC_DATA_CLUSTER_ABUNDANCE_SAMPLING", "sampling" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcDataClusterAbundanceId"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "data/nc_data_distance_mu.h" */
GType
nc_data_distance_mu_sn_ia_id_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_DATA_DISTANCE_MU_SNIA_GOLD_157, "NC_DATA_DISTANCE_MU_SNIA_GOLD_157", "gold-157" },
        { NC_DATA_DISTANCE_MU_SNIA_GOLD_182, "NC_DATA_DISTANCE_MU_SNIA_GOLD_182", "gold-182" },
        { NC_DATA_DISTANCE_MU_SNIA_GOLD_182_FULL, "NC_DATA_DISTANCE_MU_SNIA_GOLD_182_FULL", "gold-182-full" },
        { NC_DATA_DISTANCE_MU_SNIA_ESSENCE, "NC_DATA_DISTANCE_MU_SNIA_ESSENCE", "essence" },
        { NC_DATA_DISTANCE_MU_SNIA_LEGACY, "NC_DATA_DISTANCE_MU_SNIA_LEGACY", "legacy" },
        { NC_DATA_DISTANCE_MU_SNIA_UNION, "NC_DATA_DISTANCE_MU_SNIA_UNION", "union" },
        { NC_DATA_DISTANCE_MU_SNIA_CfA3, "NC_DATA_DISTANCE_MU_SNIA_CfA3", "cfa3" },
        { NC_DATA_DISTANCE_MU_SNIA_UNION2, "NC_DATA_DISTANCE_MU_SNIA_UNION2", "union2" },
        { NC_DATA_DISTANCE_MU_SNIA_UNION2_1, "NC_DATA_DISTANCE_MU_SNIA_UNION2_1", "union2-1" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcDataDistanceMuSNIaId"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "data/nc_data_hubble.h" */
GType
nc_data_hubble_id_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_DATA_HUBBLE_VERDE, "NC_DATA_HUBBLE_VERDE", "verde" },
        { NC_DATA_HUBBLE_CABRE, "NC_DATA_HUBBLE_CABRE", "cabre" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcDataHubbleId"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "data/nc_data_bao.h" */
GType
nc_data_bao_id_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_DATA_BAO_A_EISENSTEIN, "NC_DATA_BAO_A_EISENSTEIN", "a-eisenstein" },
        { NC_DATA_BAO_DV_EISENSTEIN, "NC_DATA_BAO_DV_EISENSTEIN", "dv-eisenstein" },
        { NC_DATA_BAO_R_DV_PERCIVAL, "NC_DATA_BAO_R_DV_PERCIVAL", "r-dv-percival" },
        { NC_DATA_BAO_DV_DV_PERCIVAL, "NC_DATA_BAO_DV_DV_PERCIVAL", "dv-dv-percival" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcDataBaoId"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 
/* enumerations from "data/nc_data_cmb.h" */
GType
nc_data_cmb_id_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;

  if (g_once_init_enter (&g_define_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { NC_DATA_CMB_SHIFT_PARAMETER_WMAP3, "NC_DATA_CMB_SHIFT_PARAMETER_WMAP3", "shift-parameter-wmap3" },
        { NC_DATA_CMB_SHIFT_PARAMETER_WMAP5, "NC_DATA_CMB_SHIFT_PARAMETER_WMAP5", "shift-parameter-wmap5" },
        { NC_DATA_CMB_DISTANCE_PRIORS_WMAP5, "NC_DATA_CMB_DISTANCE_PRIORS_WMAP5", "distance-priors-wmap5" },
        { NC_DATA_CMB_SHIFT_PARAMETER_WMAP7, "NC_DATA_CMB_SHIFT_PARAMETER_WMAP7", "shift-parameter-wmap7" },
        { NC_DATA_CMB_DISTANCE_PRIORS_WMAP7, "NC_DATA_CMB_DISTANCE_PRIORS_WMAP7", "distance-priors-wmap7" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("NcDataCMBId"), values);
      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
    }

  return g_define_type_id__volatile;
}
 

/* Generated data ends here */

